@@ -7,14 +7,14 @@ import rips
 import time
 import grpc
 
-resinsight     = rips.Instance.find()
+resinsight = rips.Instance.find()
 start = time.time()
 case = resinsight.project.cases()[0]
 
 # Read poro result into list
-poro_results = case.active_cell_property('STATIC_NATIVE', 'PORO', 0)
+poro_results = case.active_cell_property("STATIC_NATIVE", "PORO", 0)
 # Read permx result into list
-permx_results = case.active_cell_property('STATIC_NATIVE', 'PERMX', 0)
+permx_results = case.active_cell_property("STATIC_NATIVE", "PERMX", 0)
 
 # Generate output result
 results = []
@@ -23,7 +23,7 @@ for (poro, permx) in zip(poro_results, permx_results):
 
 try:
     # Send back output result
-    case.set_active_cell_property(results, 'GENERATED', 'POROPERMXSY', 0)
+    case.set_active_cell_property(results, "GENERATED", "POROPERMXSY", 0)
 except grpc.RpcError as e:
     print("Exception Received: ", e)
 
@@ -32,4 +32,4 @@ end = time.time()
 print("Time elapsed: ", end - start)
 print("Transferred all results back")
 
-view = case.views()[0].apply_cell_result('GENERATED', 'POROPERMXSY')
\ No newline at end of file
+view = case.views()[0].apply_cell_result("GENERATED", "POROPERMXSY")
