@@ -3,7 +3,7 @@
 ######################################################################
 import rips
 
-resinsight  = rips.Instance.find()
+resinsight = rips.Instance.find()
 
 view = resinsight.project.views()[0]
-view.apply_cell_result(result_type='STATIC_NATIVE', result_variable='DX')
+view.apply_cell_result(result_type="STATIC_NATIVE", result_variable="DX")
